@@ -30,15 +30,11 @@
 
 #include <connector/c/include/tarantool/tnt_proto.h>
 #include <connector/c/include/tarantool/tnt_tuple.h>
+#include <connector/c/include/tarantool/tnt_request.h>
 #include <connector/c/include/tarantool/tnt_reply.h>
 #include <connector/c/include/tarantool/tnt_stream.h>
 #include <connector/c/include/tarantool/tnt_insert.h>
 
-struct tnt_header_insert {
-	uint32_t ns;
-	uint32_t flags;
-};
-
 /*
  * tnt_insert()
  *
