@@ -29,7 +29,9 @@
 #include <string.h>
 
 #include <connector/c/include/tarantool/tnt_mem.h>
+#include <connector/c/include/tarantool/tnt_proto.h>
 #include <connector/c/include/tarantool/tnt_tuple.h>
+#include <connector/c/include/tarantool/tnt_request.h>
 #include <connector/c/include/tarantool/tnt_reply.h>
 #include <connector/c/include/tarantool/tnt_stream.h>
 
@@ -52,6 +54,29 @@ tnt_stream_reqid(struct tnt_stream *s, uint32_t reqid)
 	return old;
 }
 
+/*
+ * tnt_stream_init()
+ *
+ * free stream object.
+ *
+ * s - stream pointer
+ *
+*/
+struct tnt_stream*
+tnt_stream_init(struct tnt_stream *s)
+{
+	if (s) {
+		memset(s, 0, sizeof(struct tnt_stream));
+		return s;
+	}
+	s = tnt_mem_alloc(sizeof(struct tnt_stream));
+	if (s == NULL)
+		return NULL;
+	memset(s, 0, sizeof(struct tnt_stream));
+	s->alloc = 1;
+	return s;
+}
+
 /*
  * tnt_stream_free()
  *
@@ -66,4 +91,3 @@ void tnt_stream_free(struct tnt_stream *s) {
 	if (s->alloc)
 		tnt_mem_free(s);
 }
-
