@@ -33,19 +33,6 @@
 #include <connector/c/include/tarantool/tnt_net.h>
 #include <connector/c/include/tarantool/tnt_io.h>
 
-static struct tnt_stream *tnt_net_tryalloc(struct tnt_stream *s) {
-	if (s) {
-		memset(s, 0, sizeof(struct tnt_stream));
-		return s;
-	}
-	s = tnt_mem_alloc(sizeof(struct tnt_stream));
-	if (s == NULL)
-		return NULL;
-	memset(s, 0, sizeof(struct tnt_stream));
-	s->alloc = 1;
-	return s;
-}
-
 static void tnt_net_free(struct tnt_stream *s) {
 	struct tnt_stream_net *sn = TNT_SNET_CAST(s);
 	tnt_io_close(sn);
@@ -81,7 +68,12 @@ tnt_net_writev(struct tnt_stream *s, struct iovec *iov, int count) {
 }
 
 static ssize_t
-tnt_net_reply_cb(struct tnt_stream *s, char *buf, ssize_t size) {
+tnt_net_write_request(struct tnt_stream *s, struct tnt_request *r) {
+	return tnt_net_writev(s, r->v, r->vc);
+}
+
+static ssize_t
+tnt_net_recv_cb(struct tnt_stream *s, char *buf, ssize_t size) {
 	struct tnt_stream_net *sn = TNT_SNET_CAST(s);
 	return tnt_io_recv(sn, buf, size);
 }
@@ -91,7 +83,13 @@ tnt_net_reply(struct tnt_stream *s, struct tnt_reply *r) {
 	if (s->wrcnt == 0)
 		return 1;
 	s->wrcnt--;
-	return tnt_reply_from(r, (tnt_replyf_t)tnt_net_reply_cb, s);
+	return tnt_reply_from(r, (tnt_reply_t)tnt_net_recv_cb, s);
+}
+
+static int
+tnt_net_request(struct tnt_stream *s, struct tnt_request *r) {
+	/* read doesn't touches wrcnt */
+	return tnt_request_from(r, (tnt_request_t)tnt_net_recv_cb, s, NULL);
 }
 
 /*
@@ -107,7 +105,7 @@ tnt_net_reply(struct tnt_stream *s, struct tnt_reply *r) {
 */
 struct tnt_stream *tnt_net(struct tnt_stream *s) {
 	int allocated = s == NULL;
-	s = tnt_net_tryalloc(s);
+	s = tnt_stream_init(s);
 	if (s == NULL)
 		return NULL;
 	/* allocating stream data */
@@ -120,9 +118,11 @@ struct tnt_stream *tnt_net(struct tnt_stream *s) {
 	memset(s->data, 0, sizeof(struct tnt_stream_net));
 	/* initializing interfaces */
 	s->read = tnt_net_read;
-	s->reply = tnt_net_reply;
+	s->read_reply = tnt_net_reply;
+	s->read_request = tnt_net_request;
 	s->write = tnt_net_write;
 	s->writev = tnt_net_writev;
+	s->write_request = tnt_net_write_request;
 	s->free = tnt_net_free;
 	/* initializing internal data */
 	struct tnt_stream_net *sn = TNT_SNET_CAST(s);
