@@ -27,7 +27,6 @@
  * SUCH DAMAGE.
  */
 #include "request.h"
-#include <objc/runtime.h>
 #include "txn.h"
 #include "tuple.h"
 #include "index.h"
@@ -940,7 +939,8 @@ do_update_ops(struct update_cmd *cmd, struct tuple *new_tuple)
 + (Request *) alloc
 {
 	size_t sz = class_getInstanceSize(self);
-	id new = palloc(fiber->gc_pool, sz);
+	id new = palloca(fiber->gc_pool, sz, sizeof(void *));
+	memset(new, 0, sz);
 	object_setClass(new, self);
 	return new;
 }
@@ -989,6 +989,3 @@ do_update_ops(struct update_cmd *cmd, struct tuple *new_tuple)
 }
 @end
 
-/**
- * vim: foldmethod=marker
- */
