@@ -590,6 +590,12 @@ box_lua_fiber_run(void *arg __attribute__((unused)))
 		lua_pushboolean(L, false);
 		/* error message */
 		lua_pushstring(L, e->errmsg);
+	} @catch (tnt_Exception *e) {
+		@throw;
+	} @catch (...) {
+		lua_settop(L, 1);
+		lua_pushboolean(L, false);
+		lua_insert(L, -2);
 	} @finally {
 		/*
 		 * If the coroutine has detached itself, collect
@@ -939,6 +945,14 @@ lbox_pcall(struct lua_State *L)
 		lua_pushboolean(L, false);
 		/* error message */
 		lua_pushstring(L, e->errmsg);
+	} @catch (tnt_Exception *e) {
+		@throw;
+	} @catch (...) {
+		lua_settop(L, 1);
+		/* completion status */
+		lua_pushboolean(L, false);
+		/* put the completion status below the error message. */
+		lua_insert(L, -2);
 	}
 	return lua_gettop(L);
 }
@@ -1042,6 +1056,10 @@ tarantool_lua_dostring(struct lua_State *L, const char *str)
 	} @catch (ClientError *e) {
 		lua_pushstring(L, e->errmsg);
 		return 1;
+	} @catch (tnt_Exception *e) {
+		@throw;
+	} @catch (...) {
+		return 1;
 	}
 	return 0;
 }
@@ -1132,6 +1150,21 @@ tarantool_lua_load_cfg(struct lua_State *L, struct tarantool_cfg *cfg)
 		}
 		free(value);
 	}
+	if (cfg->memcached_port) {
+		lua_pushfstring(L,
+		"box.space[%d].enabled = true\n"
+		"box.space[%d].cardinality = 4\n"
+		"box.space[%d].estimated_rows = 0\n"
+		"box.space[%d].index[0].unique = true\n"
+		"box.space[%d].index[0].type = 'HASH'\n"
+		"box.space[%d].index[0].key_field[0].field_no = 0\n"
+		"box.space[%d].index[0].key_field[0].field_type = 'STRING'\n",
+		cfg->memcached_space, cfg->memcached_space,
+		cfg->memcached_space, cfg->memcached_space,
+		cfg->memcached_space, cfg->memcached_space,
+		cfg->memcached_space);
+		luaL_addvalue(&b);
+	}
 	luaL_addstring(&b,
 		       "getmetatable(box.cfg).__newindex = "
 		       "function(table, index)\n"
@@ -1222,6 +1255,3 @@ tarantool_lua_load_init_script(struct lua_State *L)
 
 }
 
-/*
- * vim: foldmethod=marker
- */
